@@ -244,9 +244,9 @@ class manager(controllers.BaseController):
         app_info = {}
         try:
             app_info = {
-                'version': cli.getConfStanza('app', 'launcher')['version'],
-                'revision': cli.getConfStanza('app', 'install')['build'],
-                'splunk_version': cli.getConfStanza('package', 'splunk')['version']
+                'version': utils.get_default_conf('app', 'launcher')['version'],
+                'revision': utils.get_default_conf('app', 'install')['build'],
+                'splunk_version': utils.get_default_conf('package', 'splunk')['version']
             }
         except Exception as e:
             self.logger.error("manager: error reading App's info." + str(e))
@@ -256,7 +256,7 @@ class manager(controllers.BaseController):
         finally:
             return jsonbak.dumps(app_info)
 
-    @expose_page(must_login=False, methods=['GET'])
+    @expose_page(must_login=True, methods=['GET'])
     def get_api(self, **kwargs):
         """
         Obtain Wazuh API from DB.
@@ -291,7 +291,7 @@ class manager(controllers.BaseController):
                 }
             )
 
-    @expose_page(must_login=False, methods=['GET'])
+    @expose_page(must_login=True, methods=['GET'])
     def get_apis(self, **kwargs):
         """
         Obtain all Wazuh APIs from DB.
@@ -324,7 +324,7 @@ class manager(controllers.BaseController):
                     "error": str(e)
                 }
             )
-            self.logger.error(error)
+            self.logger.error("manager::get_apis(): %s" % (error))
             return error
 
     @expose_page(must_login=False, methods=['POST'])
@@ -522,7 +522,7 @@ class manager(controllers.BaseController):
                 )
         return result
 
-    @expose_page(must_login=False, methods=['GET'])
+    @expose_page(must_login=True, methods=['GET'])
     def check_connection_by_id(self, **kwargs):
         """
         Check API connection AFTER registration.
@@ -727,7 +727,7 @@ class manager(controllers.BaseController):
             )
 
             api_version = utils.get_parameter(response, 'data')['api_version']
-            app_version = cli.getConfStanza('app', 'launcher')['version']
+            app_version = utils.get_default_conf('app', 'launcher')['version']
 
             if api_version != app_version:
                 raise Exception(
