@@ -66,6 +66,13 @@ define([
         $notificationService
       )
       this.rootScope = $rootScope
+
+      const DEFAULT_METRIC_VALUES = '-'
+      this.scope.totalAlerts = DEFAULT_METRIC_VALUES
+      this.scope.levelTwelve = DEFAULT_METRIC_VALUES
+      this.scope.authFailure = DEFAULT_METRIC_VALUES
+      this.scope.authSuccess = DEFAULT_METRIC_VALUES
+
       this.scope.reportingEnabled = reportingEnabled
       this.scope.awsExtensionEnabled = awsExtensionEnabled
       this.apiReq = $requestService.apiReq
