@@ -5,7 +5,8 @@ define(['../module'], function (module) {
     '$http',
     '$apiIndexStorageService',
     '$q',
-    function ($https, $apiIndexStorageService, $q) {
+    '$modelFactory',
+    function ($https, $apiIndexStorageService, $q, $modelFactory) {
       constructor
       /**
        * Generated and returns the browser base URL + Splunk Port
@@ -184,6 +185,32 @@ define(['../module'], function (module) {
         }
       }
 
+      /**
+       * Performs a request to the Wazuh API and returns its response in a model.
+       * @param {String} endpoint 
+       * @param {Object} opts body parameters
+       * @param {String} method any Http method - GET, POST, PUT, DELETE
+       * @returns 
+       */
+      const apiReqInModel = async (endpoint, opts = null, method = 'GET') => {
+        let responseModel = $modelFactory.getResponse()
+        try {
+          const results = await apiReq(endpoint, opts, method)
+          
+          // No response (timeout exceeded or similar)
+          if (results.data.error) {
+            throw new Error(results.data.error)
+          }
+
+          // Response arrived
+          responseModel = $modelFactory.getResponse(results.data)
+        } catch (error) {
+          responseModel.setError()
+          responseModel.setMessage(error)
+        }
+        return responseModel
+      }
+
       const service = {
         getBaseUrl: getBaseUrl,
         getWellFormedUri: getWellFormedUri,
@@ -193,6 +220,7 @@ define(['../module'], function (module) {
         sendGroupConfiguration: sendGroupConfiguration,
         getConfiguration: getConfiguration,
         wazuhIsReady: wazuhIsReady,
+        apiReqInModel: apiReqInModel,
       }
       return service
     },
